dlk.core.layers.embeddings package
==================================

Submodules
----------

dlk.core.layers.embeddings.combine\_word\_char\_cnn module
----------------------------------------------------------

.. automodule:: dlk.core.layers.embeddings.combine_word_char_cnn
   :members:
   :undoc-members:
   :show-inheritance:

dlk.core.layers.embeddings.identity module
------------------------------------------

.. automodule:: dlk.core.layers.embeddings.identity
   :members:
   :undoc-members:
   :show-inheritance:

dlk.core.layers.embeddings.pretrained\_transformers module
----------------------------------------------------------

.. automodule:: dlk.core.layers.embeddings.pretrained_transformers
   :members:
   :undoc-members:
   :show-inheritance:

dlk.core.layers.embeddings.random module
----------------------------------------

.. automodule:: dlk.core.layers.embeddings.random
   :members:
   :undoc-members:
   :show-inheritance:

dlk.core.layers.embeddings.static module
----------------------------------------

.. automodule:: dlk.core.layers.embeddings.static
   :members:
   :undoc-members:
   :show-inheritance:

dlk.core.layers.embeddings.static\_char\_cnn module
---------------------------------------------------

.. automodule:: dlk.core.layers.embeddings.static_char_cnn
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dlk.core.layers.embeddings
   :members:
   :undoc-members:
   :show-inheritance:
